@@ -15,7 +15,7 @@ class GetWeather(BaseModel):
 client = OpenAI()
 
 
-with client.beta.chat.completions.stream(
+with client.chat.completions.stream(
     model="gpt-4o-2024-08-06",
     messages=[
         {
