@@ -37,7 +37,7 @@ from ..._parsing import (
     parse_function_tool_arguments,
 )
 from ...._streaming import Stream, AsyncStream
-from ....types.chat import ChatCompletionChunk, ParsedChatCompletion, ChatCompletionToolParam
+from ....types.chat import ChatCompletionChunk, ParsedChatCompletion, ChatCompletionToolUnionParam
 from ...._exceptions import LengthFinishReasonError, ContentFilterFinishReasonError
 from ....types.chat.chat_completion import ChoiceLogprobs
 from ....types.chat.chat_completion_chunk import Choice as ChoiceChunk
@@ -58,7 +58,7 @@ class ChatCompletionStream(Generic[ResponseFormatT]):
         *,
         raw_stream: Stream[ChatCompletionChunk],
         response_format: type[ResponseFormatT] | ResponseFormatParam | NotGiven,
-        input_tools: Iterable[ChatCompletionToolParam] | NotGiven,
+        input_tools: Iterable[ChatCompletionToolUnionParam] | NotGiven,
     ) -> None:
         self._raw_stream = raw_stream
         self._response = raw_stream.response
@@ -113,6 +113,8 @@ class ChatCompletionStream(Generic[ResponseFormatT]):
 
     def __stream__(self) -> Iterator[ChatCompletionStreamEvent[ResponseFormatT]]:
         for sse_event in self._raw_stream:
+            if not _is_valid_chat_completion_chunk_weak(sse_event):
+                continue
             events_to_fire = self._state.handle_chunk(sse_event)
             for event in events_to_fire:
                 yield event
@@ -126,7 +128,7 @@ class ChatCompletionStreamManager(Generic[ResponseFormatT]):
 
     Usage:
     ```py
-    with client.beta.chat.completions.stream(...) as stream:
+    with client.chat.completions.stream(...) as stream:
         for event in stream:
             ...
     ```
@@ -137,7 +139,7 @@ class ChatCompletionStreamManager(Generic[ResponseFormatT]):
         api_request: Callable[[], Stream[ChatCompletionChunk]],
         *,
         response_format: type[ResponseFormatT] | ResponseFormatParam | NotGiven,
-        input_tools: Iterable[ChatCompletionToolParam] | NotGiven,
+        input_tools: Iterable[ChatCompletionToolUnionParam] | NotGiven,
     ) -> None:
         self.__stream: ChatCompletionStream[ResponseFormatT] | None = None
         self.__api_request = api_request
@@ -179,7 +181,7 @@ class AsyncChatCompletionStream(Generic[ResponseFormatT]):
         *,
         raw_stream: AsyncStream[ChatCompletionChunk],
         response_format: type[ResponseFormatT] | ResponseFormatParam | NotGiven,
-        input_tools: Iterable[ChatCompletionToolParam] | NotGiven,
+        input_tools: Iterable[ChatCompletionToolUnionParam] | NotGiven,
     ) -> None:
         self._raw_stream = raw_stream
         self._response = raw_stream.response
@@ -234,6 +236,8 @@ class AsyncChatCompletionStream(Generic[ResponseFormatT]):
 
     async def __stream__(self) -> AsyncIterator[ChatCompletionStreamEvent[ResponseFormatT]]:
         async for sse_event in self._raw_stream:
+            if not _is_valid_chat_completion_chunk_weak(sse_event):
+                continue
             events_to_fire = self._state.handle_chunk(sse_event)
             for event in events_to_fire:
                 yield event
@@ -247,7 +251,7 @@ class AsyncChatCompletionStreamManager(Generic[ResponseFormatT]):
 
     Usage:
     ```py
-    async with client.beta.chat.completions.stream(...) as stream:
+    async with client.chat.completions.stream(...) as stream:
         for event in stream:
             ...
     ```
@@ -258,7 +262,7 @@ class AsyncChatCompletionStreamManager(Generic[ResponseFormatT]):
         api_request: Awaitable[AsyncStream[ChatCompletionChunk]],
         *,
         response_format: type[ResponseFormatT] | ResponseFormatParam | NotGiven,
-        input_tools: Iterable[ChatCompletionToolParam] | NotGiven,
+        input_tools: Iterable[ChatCompletionToolUnionParam] | NotGiven,
     ) -> None:
         self.__stream: AsyncChatCompletionStream[ResponseFormatT] | None = None
         self.__api_request = api_request
@@ -310,7 +314,7 @@ class ChatCompletionStreamState(Generic[ResponseFormatT]):
     def __init__(
         self,
         *,
-        input_tools: Iterable[ChatCompletionToolParam] | NotGiven = NOT_GIVEN,
+        input_tools: Iterable[ChatCompletionToolUnionParam] | NotGiven = NOT_GIVEN,
         response_format: type[ResponseFormatT] | ResponseFormatParam | NotGiven = NOT_GIVEN,
     ) -> None:
         self.__current_completion_snapshot: ParsedChatCompletionSnapshot | None = None
@@ -434,6 +438,8 @@ class ChatCompletionStreamState(Generic[ResponseFormatT]):
                 choice_snapshot.message.content
                 and not choice_snapshot.message.refusal
                 and is_given(self._rich_response_format)
+                # partial parsing fails on white-space
+                and choice_snapshot.message.content.lstrip()
             ):
                 choice_snapshot.message.parsed = from_json(
                     bytes(choice_snapshot.message.content, "utf-8"),
@@ -578,7 +584,7 @@ class ChatCompletionStreamState(Generic[ResponseFormatT]):
 
 
 class ChoiceEventState:
-    def __init__(self, *, input_tools: list[ChatCompletionToolParam]) -> None:
+    def __init__(self, *, input_tools: list[ChatCompletionToolUnionParam]) -> None:
         self._input_tools = input_tools
 
         self._content_done = False
@@ -753,3 +759,12 @@ def _convert_initial_chunk_into_snapshot(chunk: ChatCompletionChunk) -> ParsedCh
             },
         ),
     )
+
+
+def _is_valid_chat_completion_chunk_weak(sse_event: ChatCompletionChunk) -> bool:
+    # Although the _raw_stream is always supposed to contain only objects adhering to ChatCompletionChunk schema,
+    # this is broken by the Azure OpenAI in case of Asynchronous Filter enabled.
+    # An easy filter is to check for the "object" property:
+    # - should be "chat.completion.chunk" for a ChatCompletionChunk;
+    # - is an empty string for Asynchronous Filter events.
+    return sse_event.object == "chat.completion.chunk"  # type: ignore # pylance reports this as a useless check
